#! /usr/bin/python3 -OOt

import sys

command = sys.argv[0]
print("Running " + command)
print("With the following arguments:")
for arg in sys.argv:
    if command == arg:
        continue
    else:
        print(arg)





'''
                This is a dummy file for translating Nemo Action files

                It was generated by the extract_action_strings script on 2020-11-26 13:52:22.096149 UTC.
'''
                
set-as-background_nemo_action_in_Name = _("Set as Wallpaper...")
set-as-background_nemo_action_in_Tooltip = _("Set the selected image as your Cinnamon desktop wallpaper")
add-desklets_nemo_action_in_Name = _("Add Desklets")
add-desklets_nemo_action_in_Tooltip = _("Add Cinamon desklets")
mount-archive_nemo_action_in_Name = _("Mount archive")
mount-archive_nemo_action_in_Tooltip = _("Mount %f to browse its contents")
change-background_nemo_action_in_Name = _("Change Desktop _Background")
change-background_nemo_action_in_Tooltip = _("Change the Cinnamon desktop background")
92_show-expo_nemo_action_in_Name = _("Manage workspaces (Expo)")
92_show-expo_nemo_action_in_Tooltip = _("Open Expo to add, remove, or organize workspaces")
new-launcher_nemo_action_in_Name = _("Create a new l_auncher here...")
new-launcher_nemo_action_in_Tooltip = _("Create a new launcher in this folder")
91_delete-workspace_nemo_action_in_Name = _("Remove workspace")
91_delete-workspace_nemo_action_in_Tooltip = _("Remove the currently active workspace")
90_new-workspace_nemo_action_in_Name = _("Jump to new workspace")
90_new-workspace_nemo_action_in_Tooltip = _("Create a new workspace and activate it")
